==> evolvotron_0.5.0.orig.tar.gz: evolvotron/libfunction/function_constant.h <==
// Source file for evolvotron
// Copyright (C) 2007 Tim Day
/*
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*! \file
  \brief Interfaces and implementation for specific Function class.
*/

#ifndef _function_constant_h_
#define _function_constant_h_

 

//------------------------------------------------------------------------------------------

//! Function class representing a constant value.
FUNCTION_BEGIN(FunctionConstant,3,0,false,FnCore)
  
  //! Returns the constant value
  virtual const XYZ evaluate(const XYZ&) const
    {
      return XYZ(param(0),param(1),param(2));
    }

  //! Returns true, obviously.
  /*! One of the few cases this method is overriden; most (all?) other no-argument functions should return false
   */
  virtual const bool is_constant() const
    {
      return true;
    }

FUNCTION_END(FunctionConstant)

//------------------------------------------------------------------------------------------

#endif

==> evolvotron_0.6.1.orig.tar.gz: evolvotron/libfunction/function_constant.h <==
// Source file for evolvotron
// Copyright (C) 2007 Tim Day
/*
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*! \file
  \brief Interfaces and implementation for specific Function class.
*/

#ifndef _function_constant_h_
#define _function_constant_h_

//------------------------------------------------------------------------------------------

//! Function class representing a constant value.
FUNCTION_BEGIN(FunctionConstant,3,0,false,FnCore)
  
  //! Returns the constant value
  virtual const XYZ evaluate(const XYZ&) const
    {
      return XYZ(param(0),param(1),param(2));
    }

  //! Returns true, obviously.
  /*! One of the few cases this method is overriden; most (all?) other no-argument functions should return false
   */
  virtual bool is_constant() const
    {
      return true;
    }

FUNCTION_END(FunctionConstant)

//------------------------------------------------------------------------------------------

#endif
